pub type UnparsedValue = ThinVec<UnparsedSegment>;Expand description
An unparsed value used by the Typed OM.
This corresponds to CSSUnparsedValue in the Typed OM specification. It
is used for values that cannot be reified into a more specific
property-agnostic representation and therefore need to preserve their
token-like structure as a sequence of string fragments and variable
references.
The underlying list of segments corresponds to the [[tokens]] internal
slot of CSSUnparsedValue.
This is represented as a type alias over ThinVec<UnparsedSegment> rather
than a dedicated struct. This avoids the need for additional wrapper types
when embedding unparsed values within other structures, while still
allowing recursive representations via the segment list.
Aliased Type
#[repr(C)]pub struct UnparsedValue { /* private fields */ }